# AutoTVM 的工作原理

1. 将计算图分割为多个子图。
2. 预测每个子图的大小。
3. 分配时间为每个子图寻找最佳执行方法。
4. 将每个子图的最佳执行方法组合起来，执行整个计算图。

AutoTVM 能计算每种方法的实际运行时间，从而收集真实数据用以训练成本模型，令成本模型预测未来某种方法的所需时间。这种做法的好处是，由于成本模型是根据运行时产生的数据训练的，所以它可以适应任何硬件，坏处是等待成本模型训练完善需要更长时间。